Sizing class

Constructors

Sizing()
factory

Properties

factor double
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortRatio double
no setter

Methods

applyFactor(double scaledValue, double newFactor) double
customScaleValue(num size) double
linearScale(num size) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
powerScale(num size) double
screenHeight(num size) double
screenWidth(num size) double
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Sizing
no setter

Static Methods

init(BoxConstraints constraints, {Size baseSize = const Size(390, 850), bool respectSystemFontScale = true, bool scaleLayoutWithFont = true, double factor = 0.5, double textScaleFactor = 1.0, CustomScaleFunction? customScale}) → void